@@ -1,4 +1,4 @@
 library(testthat)
 library(CDECRetrieve)
 
-#test_check("CDECRetrieve")
+test_check("CDECRetrieve")
